SANAJEH
=======
Simulate ECoG and fMRI data in Python based on BIDS

Features
--------
- Pure Python

Installation
------------
Install won by running:

    pip install sanajeh

Requirements
------------
- Python 3.6
- bidso
- wonambi
- nibabel

Status
------
.. image:: https://travis-ci.org/gpiantoni/sanajeh.svg?branch=master
    :target: https://travis-ci.org/gpiantoni/sanajeh

.. image:: https://codecov.io/gh/gpiantoni/sanajeh/branch/master/graph/badge.svg
    :target: https://codecov.io/gh/gpiantoni/sanajeh

License
-------
The project is licensed under the MIT license.
